@@ -6,10 +6,14 @@
 #' @import rlang
 #' @importFrom ggplot2 %+%
 #' @importFrom ggplot2 ggplot_add
-#' @importFrom dplyr desc
+#' @importFrom dplyr desc across all_of n
 #' @docType package
 NULL
 
 #' @importFrom ggplot2 aes
 #' @export
 ggplot2::aes
+
+# TODO: where() is not exported from tidyselect.
+#       Fix this when r-lib/tidyselect#201 is closed.
+utils::globalVariables("where")
